@@ -1,3 +1,4 @@
+import math
 import typing
 import uuid
 from dataclasses import dataclass, field
@@ -32,11 +33,17 @@ class MultivariateFeatureStateValueModel:
     mv_fs_value_uuid: str = field(default_factory=uuid.uuid4)
 
 
+@dataclass
+class FeatureSegmentModel:
+    priority: int = None
+
+
 @dataclass
 class FeatureStateModel:
     feature: FeatureModel
     enabled: bool
     django_id: int = None
+    feature_segment: FeatureSegmentModel = None
     featurestate_uuid: str = field(default_factory=uuid.uuid4)
     feature_state_value: typing.Any = field(default=None, init=False)
     multivariate_feature_state_values: typing.List[
@@ -58,6 +65,34 @@ class FeatureStateModel:
             return self._get_multivariate_value(identity_id)
         return self.feature_state_value
 
+    def is_higher_segment_priority(self, other: "FeatureStateModel") -> bool:
+        """
+        Returns `True` if `self` is higher segment priority than `other`
+        (i.e. has lower value for feature_segment.priority)
+
+        NOTE:
+            A segment will be considered higher priority only if:
+            1. `other` does not have a feature segment(i.e: it is an environment feature state or it's a
+            feature state with feature segment but from an old document that does not have `feature_segment.priority`)
+            but `self` does.
+
+            2. `other` have a feature segment with high priority
+
+        """
+
+        try:
+            return (
+                getattr(
+                    self.feature_segment,
+                    "priority",
+                    math.inf,
+                )
+                < other.feature_segment.priority
+            )
+
+        except (TypeError, AttributeError):
+            return False
+
     def _get_multivariate_value(
         self, identity_id: typing.Union[int, str]
     ) -> typing.Any:
