@@ -16,6 +16,9 @@ NOT_CONTAINS = "NOT_CONTAINS"
 NOT_EQUAL = "NOT_EQUAL"
 REGEX = "REGEX"
 PERCENTAGE_SPLIT = "PERCENTAGE_SPLIT"
+MODULO = "MODULO"
+IS_SET = "IS_SET"
+IS_NOT_SET = "IS_NOT_SET"
 
 CONDITION_OPERATORS = [
     EQUAL,
@@ -28,4 +31,7 @@ CONDITION_OPERATORS = [
     NOT_EQUAL,
     REGEX,
     PERCENTAGE_SPLIT,
+    MODULO,
+    IS_SET,
+    IS_NOT_SET,
 ]
