@@ -16,10 +16,11 @@ class SegmentConditionModel:
     EXCEPTION_OPERATOR_METHODS = {
         constants.NOT_CONTAINS: "evaluate_not_contains",
         constants.REGEX: "evaluate_regex",
+        constants.MODULO: "evaluate_modulo",
     }
 
     operator: str
-    value: str
+    value: str = None
     property_: str = None
 
     def matches_trait_value(self, trait_value: typing.Any) -> bool:
@@ -56,6 +57,17 @@ class SegmentConditionModel:
     def evaluate_regex(self, trait_value: str) -> bool:
         return re.compile(str(self.value)).match(trait_value) is not None
 
+    def evaluate_modulo(self, trait_value: typing.Union[str, int, float, bool]) -> bool:
+        if type(trait_value) not in (int, float):
+            return False
+        try:
+            divisor, remainder = self.value.split("|")
+            divisor = float(divisor)
+            remainder = float(remainder)
+        except ValueError:
+            return False
+        return trait_value % divisor == remainder
+
 
 @dataclass
 class SegmentRuleModel:
